@@ -4,13 +4,9 @@ from typing import Any
 from django import forms
 from django.contrib import admin
 from nango import forms
-from nango.common import set_original_form_values_on_instance
 
-
-class AdminMixin:
-    def save_model(self, request, obj, form, change):
-        set_original_form_values_on_instance(form=form, instance=obj)
-        return super().save_model(request=request, obj=obj, form=form, change=change)
+from . import site  # noqa
+from .admin import *  # noqa
 
 
 def __getattr__(name: str) -> Any:
@@ -45,10 +41,6 @@ def __getattr__(name: str) -> Any:
     return OriginalClass
 
 
-class ModelAdmin(AdminMixin, admin.ModelAdmin):
-    form = forms.ModelForm
-
-
 def register(*args, **kw):
     """
     You can use this in place of admin.site.register
